@@ -1,7 +1,7 @@
 package MsgPack::Encoder;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Encode a structure into a MessagePack binary string
-$MsgPack::Encoder::VERSION = '1.0.0';
+$MsgPack::Encoder::VERSION = '1.0.1';
 
 use strict;
 use warnings;
@@ -17,7 +17,7 @@ use experimental 'postderef', 'signatures';
 
 use overload '""' => \&encoded;
 
-use Types::Standard qw/ Str ArrayRef Ref Int Any InstanceOf Undef HashRef Num /;
+use Types::Standard qw/ Str ArrayRef Ref Int Any InstanceOf Undef HashRef Num StrictNum /;
 use Type::Tiny;
 
 use MsgPack::Type::Ext;
@@ -237,7 +237,7 @@ my $Ext32 = Type::Tiny->new(
 );
 
 my $Float64 = Type::Tiny->new(
-    parent => Num,
+    parent => StrictNum,
     name => 'Float64',
 );
 
@@ -489,7 +489,7 @@ MsgPack::Encoder - Encode a structure into a MessagePack binary string
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 SYNOPSIS
 
